@@ -20,16 +20,15 @@
 #define SIEVEACTIONDISCARD_H
 
 #include "sieveaction.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionDiscard : public SieveAction
 {
     Q_OBJECT
 public:
     explicit SieveActionDiscard(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString code(QWidget *) const Q_DECL_OVERRIDE;
-    QString help() const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    QString code(QWidget *) const override;
+    QString help() const override;
+    QUrl href() const override;
 };
 }
 
