@@ -24,8 +24,7 @@
 class KComboBox;
 class QLineEdit;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SelectBodyTypeWidget : public QWidget
 {
     Q_OBJECT
@@ -38,14 +37,11 @@ public:
 
 Q_SIGNALS:
     void valueChanged();
-
-private Q_SLOTS:
-    void slotBodyTypeChanged(int);
-
 private:
+    void slotBodyTypeChanged(int);
     void initialize();
-    KComboBox *mBodyCombobox;
-    QLineEdit *mBodyLineEdit;
+    KComboBox *mBodyCombobox = nullptr;
+    QLineEdit *mBodyLineEdit = nullptr;
 };
 }
 
