@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -30,7 +30,6 @@
 #include <kns3/uploaddialog.h>
 #include <KLocalizedString>
 #include <KIconLoader>
-#include <KStandardGuiItem>
 #include <QTemporaryDir>
 #include <kzip.h>
 #include <KIconEngine>
@@ -51,14 +50,10 @@
 using namespace KSieveUi;
 
 SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
-    : QWidget(parent),
-      mMode(TextMode),
-      mModified(false)
+    : QWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout;
-#if !defined(NDEBUG)
-    mGenerateXml = 0;
-#endif
+    QVBoxLayout *lay = new QVBoxLayout(this);
+    mDebug = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
 
     QToolBar *toolbar = new QToolBar;
     toolbar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
@@ -66,24 +61,23 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     mCheckSyntax = new QAction(i18n("Check Syntax"), this);
     connect(mCheckSyntax, &QAction::triggered, this, &SieveEditorWidget::slotCheckSyntax);
     toolbar->addAction(mCheckSyntax);
-    mSaveAs = KStandardAction::saveAs(this, SLOT(slotSaveAs()), this);
+    mSaveAs = KStandardAction::saveAs(this, &SieveEditorWidget::slotSaveAs, this);
     toolbar->addAction(mSaveAs);
-    toolbar->addAction(i18n("Import..."), this, SLOT(slotImport()));
+    toolbar->addAction(i18n("Import..."), this, &SieveEditorWidget::slotImport);
 
-    mAutoGenerateScript = new QAction(i18n("Autogenerate Script..."), this);
-    connect(mAutoGenerateScript, &QAction::triggered, this, &SieveEditorWidget::slotAutoGenerateScripts);
-    toolbar->addAction(mAutoGenerateScript);
+    mCreateRulesGraphically = new QAction(i18n("Create Rules Graphically..."), this);
+    connect(mCreateRulesGraphically, &QAction::triggered, this, &SieveEditorWidget::slotCreateRulesGraphically);
+    toolbar->addAction(mCreateRulesGraphically);
     mSwitchMode = new QAction(this);
     toolbar->addAction(mSwitchMode);
     connect(mSwitchMode, &QAction::triggered, this, &SieveEditorWidget::slotSwitchMode);
-#if !defined(NDEBUG)
-    if (!qEnvironmentVariableIsEmpty("KDEPIM_SIEVEEDITOR_DEBUG")) {
+
+    if (mDebug) {
         //Not necessary to translate it.
         mGenerateXml = new QAction(QStringLiteral("Generate xml"), this);
         connect(mGenerateXml, &QAction::triggered, this, &SieveEditorWidget::slotGenerateXml);
         toolbar->addAction(mGenerateXml);
     }
-#endif
 
     QStringList overlays;
     overlays << QStringLiteral("list-add");
@@ -92,9 +86,9 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     //Add action to toolBar
 
     toolbar->addAction(mShareScript);
-
+    SieveEditorMenuBar *menuBar = nullptr;
     if (useMenuBar) {
-        SieveEditorMenuBar *menuBar = new SieveEditorMenuBar;
+        menuBar = new SieveEditorMenuBar;
         connect(this, &SieveEditorWidget::changeModeEditor, menuBar, &SieveEditorMenuBar::setEditorMode);
         connect(menuBar, &SieveEditorMenuBar::copy, this, &SieveEditorWidget::copy);
         connect(menuBar, &SieveEditorMenuBar::find, this, &SieveEditorWidget::find);
@@ -112,15 +106,18 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         connect(menuBar, &SieveEditorMenuBar::zoomReset, this, &SieveEditorWidget::zoomReset);
         connect(menuBar, &SieveEditorMenuBar::debugSieveScript, this, &SieveEditorWidget::debugSieveScript);
         connect(menuBar, &SieveEditorMenuBar::wordWrap, this, &SieveEditorWidget::wordWrap);
+        connect(menuBar, &SieveEditorMenuBar::print, this, &SieveEditorWidget::print);
+        connect(menuBar, &SieveEditorMenuBar::printPreview, this, &SieveEditorWidget::printPreview);
 
         connect(this, &SieveEditorWidget::copyAvailable, menuBar, &SieveEditorMenuBar::slotCopyAvailable);
         connect(this, &SieveEditorWidget::redoAvailable, menuBar, &SieveEditorMenuBar::slotRedoAvailable);
         connect(this, &SieveEditorWidget::undoAvailable, menuBar, &SieveEditorMenuBar::slotUndoAvailable);
+        menuBar->fileMenu()->addSeparator();
         menuBar->fileMenu()->addAction(mSaveAs);
         menuBar->fileMenu()->addSeparator();
         menuBar->fileMenu()->addAction(mShareScript);
         menuBar->toolsMenu()->addSeparator();
-        menuBar->toolsMenu()->addAction(mAutoGenerateScript);
+        menuBar->toolsMenu()->addAction(mCreateRulesGraphically);
         menuBar->toolsMenu()->addAction(mCheckSyntax);
         lay->addWidget(menuBar);
     }
@@ -136,11 +133,13 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     lay->addLayout(nameLayout);
 
     lay->setMargin(0);
-    setLayout(lay);
     mStackedWidget = new QStackedWidget;
 
     mTextModeWidget = new SieveEditorTextModeWidget;
     connect(mTextModeWidget, &SieveEditorTextModeWidget::valueChanged, this, &SieveEditorWidget::slotModified);
+    if (useMenuBar) {
+        menuBar->setTextModeWidget(mTextModeWidget);
+    }
     mStackedWidget->addWidget(mTextModeWidget);
     mGraphicalModeWidget = new SieveEditorGraphicalModeWidget;
     connect(mGraphicalModeWidget, &SieveEditorGraphicalModeWidget::valueChanged, this, &SieveEditorWidget::slotModified);
@@ -154,6 +153,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     connect(mTextModeWidget, &SieveEditorTextModeWidget::undoAvailable, this, &SieveEditorWidget::undoAvailable);
     connect(mTextModeWidget, &SieveEditorTextModeWidget::redoAvailable, this, &SieveEditorWidget::redoAvailable);
     connect(mTextModeWidget, &SieveEditorTextModeWidget::copyAvailable, this, &SieveEditorWidget::copyAvailable);
+    connect(mTextModeWidget, &SieveEditorTextModeWidget::sieveEditorTabCurrentChanged, this, &SieveEditorWidget::sieveEditorTabCurrentChanged);
     if (KSieveUi::EditorSettings::useGraphicEditorByDefault()) {
         changeMode(GraphicMode);
     } else {
@@ -244,6 +244,42 @@ void SieveEditorWidget::updateOriginalScript()
     mOriginalScript = script();
 }
 
+void SieveEditorWidget::print()
+{
+    switch (mMode) {
+    case TextMode:
+    {
+        bool wasModified = isModified();
+        mTextModeWidget->print();
+        setModified(wasModified);
+        break;
+    }
+    case GraphicMode:
+        break;
+    case Unknown:
+        qCDebug(LIBKSIEVE_LOG) << " Unknown mode";
+        break;
+    }
+}
+
+void SieveEditorWidget::printPreview()
+{
+    switch (mMode) {
+    case TextMode:
+    {
+        bool wasModified = isModified();
+        mTextModeWidget->printPreview();
+        setModified(wasModified);
+        break;
+    }
+    case GraphicMode:
+        break;
+    case Unknown:
+        qCDebug(LIBKSIEVE_LOG) << " Unknown mode";
+        break;
+    }
+}
+
 void SieveEditorWidget::wordWrap(bool state)
 {
     if (mMode == TextMode) {
@@ -363,6 +399,8 @@ void SieveEditorWidget::slotShareScript()
             }
         }
         delete zip;
+    } else {
+        qCWarning(LIBKSIEVE_LOG) << "Impossible to open temp file";
     }
 }
 
@@ -372,26 +410,24 @@ void SieveEditorWidget::changeMode(EditorMode mode)
         mMode = mode;
         mStackedWidget->setCurrentIndex(static_cast<int>(mode));
         const bool isTextMode = (mMode == TextMode);
-        mAutoGenerateScript->setEnabled(isTextMode);
-#if !defined(NDEBUG)
+        mCreateRulesGraphically->setEnabled(isTextMode);
         if (mGenerateXml) {
             mGenerateXml->setEnabled(isTextMode);
         }
-#endif
         if (isTextMode) {
             mCheckSyntax->setEnabled(!mTextModeWidget->currentscript().isEmpty());
         } else {
             mCheckSyntax->setEnabled(false);
         }
         Q_EMIT modeEditorChanged(mode);
-        changeModeEditor(isTextMode);
+        Q_EMIT changeModeEditor(isTextMode);
         changeSwitchButtonText();
     }
 }
 
 void SieveEditorWidget::changeSwitchButtonText()
 {
-    mSwitchMode->setText((mMode == TextMode) ?  i18n("Simple Mode") : i18n("Advanced Mode"));
+    mSwitchMode->setText((mMode == TextMode) ? i18n("Simple Mode") : i18n("Advanced Mode"));
 }
 
 void SieveEditorWidget::slotEnableButtonOk(bool b)
@@ -427,9 +463,9 @@ QString SieveEditorWidget::originalScript() const
     return mOriginalScript;
 }
 
-void SieveEditorWidget::setScript(const QString &script)
+void SieveEditorWidget::setScript(const QString &script, bool clearUndoRedo)
 {
-    mTextModeWidget->setScript(script);
+    mTextModeWidget->setScript(script, clearUndoRedo);
     mOriginalScript = script;
 }
 
@@ -443,6 +479,11 @@ void SieveEditorWidget::addOkMessage(const QString &msg)
     addMessageEntry(msg, QColor(Qt::darkGreen));
 }
 
+void SieveEditorWidget::addNormalMessage(const QString &msg)
+{
+    addMessageEntry(msg, palette().color(QPalette::WindowText));
+}
+
 void SieveEditorWidget::addMessageEntry(const QString &errorMsg, const QColor &color)
 {
     QString msg = errorMsg;
@@ -474,11 +515,23 @@ void SieveEditorWidget::setSieveCapabilities(const QStringList &capabilities)
     mGraphicalModeWidget->setSieveCapabilities(capabilities);
 }
 
-void SieveEditorWidget::slotAutoGenerateScripts()
+void SieveEditorWidget::setSieveImapAccountSettings(const SieveImapAccountSettings &sieveImapAccountSettings)
+{
+    mGraphicalModeWidget->setSieveImapAccountSettings(sieveImapAccountSettings);
+    mTextModeWidget->setSieveImapAccountSettings(sieveImapAccountSettings);
+}
+
+void SieveEditorWidget::setListOfIncludeFile(const QStringList &listOfIncludeFile)
+{
+    mTextModeWidget->setListOfIncludeFile(listOfIncludeFile);
+    mGraphicalModeWidget->setListOfIncludeFile(listOfIncludeFile);
+}
+
+void SieveEditorWidget::slotCreateRulesGraphically()
 {
     switch (mMode) {
     case TextMode:
-        mTextModeWidget->autoGenerateScripts();
+        mTextModeWidget->createRulesGraphically();
         break;
     case GraphicMode:
     case Unknown:
@@ -501,7 +554,6 @@ void SieveEditorWidget::slotCheckSyntax()
 
 void SieveEditorWidget::slotGenerateXml()
 {
-#if !defined(NDEBUG)
     switch (mMode) {
     case TextMode:
         mTextModeWidget->generateXml();
@@ -510,7 +562,6 @@ void SieveEditorWidget::slotGenerateXml()
     case Unknown:
         break;
     }
-#endif
 }
 
 void SieveEditorWidget::checkSpelling()
@@ -564,26 +615,28 @@ void SieveEditorWidget::slotSwitchToGraphicalMode()
 void SieveEditorWidget::slotSwitchMode()
 {
     switch (mMode) {
-    case TextMode: {
+    case TextMode:
+    {
         bool result = false;
-        const QDomDocument doc = ParsingUtil::parseScript(mTextModeWidget->currentscript(), result);
+        const QString doc = ParsingUtil::parseScript(mTextModeWidget->currentscript(), result);
         if (result) {
             QString error;
             mGraphicalModeWidget->loadScript(doc, error);
-            mTextModeWidget->hideEditorWarning();
             if (!error.isEmpty()) {
                 mTextModeWidget->setParsingEditorWarningError(mTextModeWidget->currentscript(), error);
                 mTextModeWidget->showParsingEditorWarning();
             } else {
+                mTextModeWidget->hideEditorWarning();
                 changeMode(GraphicMode);
             }
         } else {
             mTextModeWidget->showEditorWarning();
-            qCDebug(LIBKSIEVE_LOG) << "cannot parse file";
+            qCDebug(LIBKSIEVE_LOG) << "Impossible to parse file";
         }
         break;
     }
-    case GraphicMode: {
+    case GraphicMode:
+    {
         const QString script = mGraphicalModeWidget->currentscript();
         changeMode(TextMode);
         mTextModeWidget->setScript(script);
@@ -658,3 +711,19 @@ QUrl SieveEditorWidget::currentHelpUrl() const
     }
     return QUrl();
 }
+
+bool SieveEditorWidget::isTextEditor() const
+{
+    if (mMode == TextMode) {
+        return mTextModeWidget->isTextEditor();
+    }
+    return false;
+}
+
+bool SieveEditorWidget::printSupportEnabled() const
+{
+    if (mMode == TextMode) {
+        return mTextModeWidget->printSupportEnabled();
+    }
+    return false;
+}
