@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,17 +20,16 @@
 
 #include <sonnet/spellcheckdecorator.h>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveTextEdit;
 class SieveTextEditorSpellCheckDecorator : public Sonnet::SpellCheckDecorator
 {
     Q_OBJECT
 public:
     explicit SieveTextEditorSpellCheckDecorator(SieveTextEdit *plainTextEdit);
-    bool isSpellCheckingEnabledForBlock(const QString &textBlock) const Q_DECL_OVERRIDE;
+    bool isSpellCheckingEnabledForBlock(const QString &textBlock) const override;
 private:
-    SieveTextEdit *mPlainTextEdit;
+    SieveTextEdit *mPlainTextEdit = nullptr;
 };
 }
 #endif // SIEVETEXTEDITORSPELLCHECKDECORATOR_H
