@@ -22,19 +22,39 @@
 #include "imapresourcesettings.h"
 #include "akonadiimapsettinginterfacetest.h"
 #include "../abstractakonadiimapsettinginterface.h"
-#include <KSieveUi/SieveImapAccountSettings>
+#include "../sieveimappasswordprovider.h"
 #include <QTest>
 
+class DataImapPasswordProvider : public KSieveUi::SieveImapPasswordProvider
+{
+public:
+    DataImapPasswordProvider(AkonadiImapSettingInterfaceDataTest *data)
+        : mData(data)
+    {
+    }
+
+    QString password(const QString & /*identifier*/) override
+    {
+        return mData->password;
+    }
+
+    QString sieveCustomPassword(const QString & /*identifier*/) override
+    {
+        return mData->sieveCustomPassword;
+    }
+
+    AkonadiImapSettingInterfaceDataTest *mData = nullptr;
+};
+
 UtilMethodTest::UtilMethodTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 void UtilMethodTest::shouldReturnEmptyInfo()
 {
     std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> interface(new KSieveUi::AbstractAkonadiImapSettingInterface);
-    KSieveUi::Util::AccountInfo info = KSieveUi::Util::findAccountInfo(QStringLiteral("foo"), false, interface);
+    KSieveUi::Util::AccountInfo info = KSieveUi::Util::findAccountInfo(QStringLiteral("dummy"), {}, false, interface);
     QVERIFY(!info.sieveImapAccountSettings.isValid());
 }
 
@@ -51,19 +71,19 @@ void UtilMethodTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QLatin1String("foo.bla.com");
-        data1.userName = QLatin1String("kde");
+        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.userName = QStringLiteral("kde");
         data1.sievePort = 543;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("SAFETY");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("SAFETY");
         data1.alternateAuthentication = -1;
         //MailTransport::Transport::EnumAuthenticationType::CRAM_MD5 = 2
         data1.authentication = 2;
         data1.sieveAlternateUrl = QString();
-        data1.password = QLatin1String("password1");
+        data1.password = QStringLiteral("password1");
         data1.sieveCustomPassword = QString();
 
         KSieveUi::Util::AccountInfo info1;
@@ -74,7 +94,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -91,19 +111,19 @@ void UtilMethodTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QLatin1String("foo.bla.com");
-        data1.userName = QLatin1String("kde");
+        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.userName = QStringLiteral("kde");
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("SAFETY");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("SAFETY");
         data1.alternateAuthentication = -1;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QLatin1String("password2");
+        data1.password = QStringLiteral("password2");
         data1.sieveCustomPassword = QString();
 
         KSieveUi::Util::AccountInfo info1;
@@ -114,7 +134,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -130,19 +150,19 @@ void UtilMethodTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QLatin1String("foo.bla.com");
-        data1.userName = QLatin1String("kde");
+        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.userName = QStringLiteral("kde");
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("SSL");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("SSL");
         data1.alternateAuthentication = -1;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QLatin1String("password2");
+        data1.password = QStringLiteral("password2");
         data1.sieveCustomPassword = QString();
 
         KSieveUi::Util::AccountInfo info1;
@@ -153,7 +173,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -170,19 +190,19 @@ void UtilMethodTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QLatin1String("foo.bla.com");
-        data1.userName = QLatin1String("kde");
+        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.userName = QStringLiteral("kde");
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("STARTTLS");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("STARTTLS");
         data1.alternateAuthentication = -1;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QLatin1String("password2");
+        data1.password = QStringLiteral("password2");
         data1.sieveCustomPassword = QString();
 
         KSieveUi::Util::AccountInfo info1;
@@ -193,7 +213,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -210,19 +230,19 @@ void UtilMethodTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = false;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QLatin1String("foo.bla.com");
-        data1.userName = QLatin1String("kde");
+        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.userName = QStringLiteral("kde");
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("SAFETY");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("SAFETY");
         data1.alternateAuthentication = -1;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QLatin1String("password2");
+        data1.password = QStringLiteral("password2");
         data1.sieveCustomPassword = QString();
 
         KSieveUi::Util::AccountInfo info1;
@@ -233,27 +253,27 @@ void UtilMethodTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QLatin1String("password3");
-        const QString imapPasswd = QLatin1String("password2");
-        const QString imapUser = QLatin1String("kde");
-        const QString sieveUser = QLatin1String("foo1");
+        const QString sievePasswd = QStringLiteral("password3");
+        const QString imapPasswd = QStringLiteral("password2");
+        const QString imapUser = QStringLiteral("kde");
+        const QString sieveUser = QStringLiteral("foo1");
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QLatin1String("foo.bla.com");
+        data1.imapServer = QStringLiteral("foo.bla.com");
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QLatin1String("CustomUserPassword");
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("SAFETY");
+        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("SAFETY");
         data1.alternateAuthentication = 4;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QLatin1String("bla.bla.com");
+        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -262,7 +282,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -274,27 +294,27 @@ void UtilMethodTest::shouldAssignValue_data()
         QTest::newRow("sievereusecustomconfig1") << data1 << info1 << true << true;
     }
     {
-        const QString sievePasswd = QLatin1String("password3");
-        const QString imapPasswd = QLatin1String("password2");
-        const QString imapUser = QLatin1String("kde");
-        const QString sieveUser = QLatin1String("foo1");
+        const QString sievePasswd = QStringLiteral("password3");
+        const QString imapPasswd = QStringLiteral("password2");
+        const QString imapUser = QStringLiteral("kde");
+        const QString sieveUser = QStringLiteral("foo1");
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QLatin1String("foo.bla.com");
+        data1.imapServer = QStringLiteral("foo.bla.com");
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QLatin1String("CustomUserPassword");
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("SAFETY");
+        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("SAFETY");
         data1.alternateAuthentication = 4;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QLatin1String("bla.bla.com");
+        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -303,7 +323,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -316,27 +336,27 @@ void UtilMethodTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QLatin1String("password3");
-        const QString imapPasswd = QLatin1String("password2");
-        const QString imapUser = QLatin1String("kde");
-        const QString sieveUser = QLatin1String("foo1");
+        const QString sievePasswd = QStringLiteral("password3");
+        const QString imapPasswd = QStringLiteral("password2");
+        const QString imapUser = QStringLiteral("kde");
+        const QString sieveUser = QStringLiteral("foo1");
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QLatin1String("foo.bla.com");
+        data1.imapServer = QStringLiteral("foo.bla.com");
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QLatin1String("CustomUserPassword");
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("SSL");
+        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("SSL");
         data1.alternateAuthentication = 4;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QLatin1String("bla.bla.com");
+        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -345,7 +365,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -358,27 +378,27 @@ void UtilMethodTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QLatin1String("password3");
-        const QString imapPasswd = QLatin1String("password2");
-        const QString imapUser = QLatin1String("kde");
-        const QString sieveUser = QLatin1String("foo1");
+        const QString sievePasswd = QStringLiteral("password3");
+        const QString imapPasswd = QStringLiteral("password2");
+        const QString imapUser = QStringLiteral("kde");
+        const QString sieveUser = QStringLiteral("foo1");
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QLatin1String("foo.bla.com");
+        data1.imapServer = QStringLiteral("foo.bla.com");
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QLatin1String("CustomUserPassword");
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("STARTTLS");
+        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("STARTTLS");
         data1.alternateAuthentication = 4;
         //MailTransport::Transport::EnumAuthenticationType::DigestMD5 = 3
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QLatin1String("bla.bla.com");
+        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -387,7 +407,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -400,27 +420,27 @@ void UtilMethodTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QLatin1String("password3");
-        const QString imapPasswd = QLatin1String("password2");
-        const QString imapUser = QLatin1String("kde");
-        const QString sieveUser = QLatin1String("foo1");
+        const QString sievePasswd = QStringLiteral("password3");
+        const QString imapPasswd = QStringLiteral("password2");
+        const QString imapUser = QStringLiteral("kde");
+        const QString sieveUser = QStringLiteral("foo1");
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QLatin1String("foo.bla.com");
+        data1.imapServer = QStringLiteral("foo.bla.com");
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QLatin1String("CustomUserPassword");
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("STARTTLS");
+        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("STARTTLS");
         data1.alternateAuthentication = 4;
         //MailTransport::Transport::EnumAuthenticationType::DigestMD5 = 3
         data1.authentication = 4;
-        data1.sieveAlternateUrl = QLatin1String("bla.bla.com");
+        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -429,7 +449,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -441,27 +461,27 @@ void UtilMethodTest::shouldAssignValue_data()
         QTest::newRow("sievereusecustomconfig1withoutvacationfileStarttls2") << data1 << info1 << true << false;
     }
     {
-        const QString sievePasswd = QLatin1String("password3");
-        const QString imapPasswd = QLatin1String("password2");
-        const QString imapUser = QLatin1String("kde");
-        const QString sieveUser = QLatin1String("foo1");
+        const QString sievePasswd = QStringLiteral("password3");
+        const QString imapPasswd = QStringLiteral("password2");
+        const QString imapUser = QStringLiteral("kde");
+        const QString sieveUser = QStringLiteral("foo1");
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QLatin1String("foo.bla.com");
+        data1.imapServer = QStringLiteral("foo.bla.com");
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QLatin1String("CustomUserPassword");
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("STARTTLS");
+        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("STARTTLS");
         data1.alternateAuthentication = 4;
         //MailTransport::Transport::EnumAuthenticationType::DigestMD5 = 3
         data1.authentication = 4;
-        data1.sieveAlternateUrl = QLatin1String("bla.bla.com");
+        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -470,7 +490,7 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QLatin1String("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -482,29 +502,28 @@ void UtilMethodTest::shouldAssignValue_data()
         QTest::newRow("sievereusecustomconfig1withoutvacationfileStarttls3") << data1 << info1 << true << false;
     }
 
-
     {
-        const QString sievePasswd = QLatin1String("password3");
-        const QString imapPasswd = QLatin1String("password2");
-        const QString imapUser = QLatin1String("kde");
-        const QString sieveUser = QLatin1String("foo1");
+        const QString sievePasswd = QStringLiteral("password3");
+        const QString imapPasswd = QStringLiteral("password2");
+        const QString imapUser = QStringLiteral("kde");
+        const QString sieveUser = QStringLiteral("foo1");
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = false;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QLatin1String("foo.bla.com");
+        data1.imapServer = QStringLiteral("foo.bla.com");
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QLatin1String("CustomUserPassword");
-        data1.sieveVacationFilename = QLatin1String("vacation.siv");
-        data1.safety = QLatin1String("STARTTLS");
+        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
+        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
+        data1.safety = QStringLiteral("STARTTLS");
         data1.alternateAuthentication = 4;
         //MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
-        data1.sieveAlternateUrl = QLatin1String("bla.bla.com");
+        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -513,7 +532,6 @@ void UtilMethodTest::shouldAssignValue_data()
         info1.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::Unencrypted);
         QTest::newRow("sievereusecustomconfig1withoutvacationfileStarttlsNoSieveSupport") << data1 << info1 << false << false;
     }
-
 }
 
 void UtilMethodTest::shouldAssignValue()
@@ -524,7 +542,8 @@ void UtilMethodTest::shouldAssignValue()
     QFETCH(bool, useVacationFile);
 
     std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> interface(new AkonadiImapSettingInterfaceTest(data));
-    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::findAccountInfo(QStringLiteral("foo"), useVacationFile, interface);
+    std::unique_ptr<DataImapPasswordProvider> provider(new DataImapPasswordProvider(&data));
+    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::findAccountInfo(QStringLiteral("foo"), provider.get(), useVacationFile, interface);
     QCOMPARE(info.sieveImapAccountSettings.isValid(), sieveImapAccountValid);
     QCOMPARE(info, accountInfo);
 }
