@@ -20,17 +20,20 @@
 
 #include <widgets/managesievewidget.h>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
+class SieveImapPasswordProvider;
 class CustomManageSieveWidget : public KSieveUi::ManageSieveWidget
 {
     Q_OBJECT
 public:
-    explicit CustomManageSieveWidget(QWidget *parent = nullptr);
+    explicit CustomManageSieveWidget(SieveImapPasswordProvider *passwordProvider, QWidget *parent = nullptr);
     virtual ~CustomManageSieveWidget();
 
 protected:
-    bool refreshList() Q_DECL_OVERRIDE;
+    bool refreshList() override;
+
+private:
+    SieveImapPasswordProvider *mPasswordProvider = nullptr;
 };
 }
 
